==> client-sdk-react-0.59.0.tgz: package/src/components/Participants/ParticipantsGridView/ParticipantsGridView.tsx <==
import React from 'react'
import { useZocksStore } from '../../../app'
import { selectLocalParticipant } from '../../../store'
import { Participant } from '../../Participant'
import './ParticipantsGridView.scss'
import { usePagedParticipants, useSortRemoteParticipantsForGridView } from '../hooks'

export const ParticipantsGridView: React.FC<{ pageSize?: number }> = ({ pageSize = 25 }) => {
  const localParticipant = useZocksStore(selectLocalParticipant)

  const remoteParticipants = useSortRemoteParticipantsForGridView(pageSize)
  const allParticipants = [localParticipant, ...remoteParticipants]

  const { displayedParticipants, hasNextPage, hasPreviousPage, nextPage, previousPage } = usePagedParticipants(
    allParticipants,
    pageSize
  )

  const gridClass = getGridClassForParticipants(Math.min(pageSize, allParticipants.length))

  return (
    <div className='participants-grid-view'>
      {hasPreviousPage && <PreviousButton onClick={previousPage} />}
      <div className={`participants-grid-view__grid ${gridClass}`}>
        {displayedParticipants.map((participant) => (
          <Participant key={participant.id} participant={participant} withAudio={true} />
        ))}
      </div>
      {hasNextPage && <NextButton onClick={nextPage} />}
    </div>
  )
}

const getGridClassForParticipants = (numberOfParticipants: number): string => {
  switch (true) {
    case numberOfParticipants <= 1:
      return 'participants-grid-view__grid--1x1'
    case numberOfParticipants === 2:
      return 'participants-grid-view__grid--2x1'
    case numberOfParticipants <= 4:
      return 'participants-grid-view__grid--2x2'
    case numberOfParticipants <= 6:
      return 'participants-grid-view__grid--3x2'
    case numberOfParticipants <= 9:
      return 'participants-grid-view__grid--3x3'
    case numberOfParticipants <= 16:
      return 'participants-grid-view__grid--4x4'
    default:
      return 'participants-grid-view__grid--5x5'
  }
}

const PreviousButton: React.FC<{ onClick: () => void }> = ({ onClick }) => (
  <button
    className='participants-grid-view__button participants-grid-view__previous-button'
    onClick={onClick}
    aria-label='Previous'
  >
    <div className='participants-grid-view__previous-button-icon' />
  </button>
)

const NextButton: React.FC<{ onClick: () => void }> = ({ onClick }) => (
  <button
    className='participants-grid-view__button participants-grid-view__next-button'
    onClick={onClick}
    aria-label='Next'
  >
    <div className='participants-grid-view__next-button-icon' />
  </button>
)

==> client-sdk-react-1.13.0.tgz: package/src/components/Participants/ParticipantsGridView/ParticipantsGridView.tsx <==
import React from 'react'
import { useZocksStore } from '../../../app'
import { selectLocalParticipant } from '../../../store'
import { Participant } from '../../Participant'
import { usePagedParticipants, useSortRemoteParticipantsForGridView } from '../hooks'
import { MultipleParticipantViewProps } from '../model'
import './ParticipantsGridView.scss'

export const ParticipantsGridView: React.FC<MultipleParticipantViewProps> = ({ pageSize = 25, participantElement }) => {
  const localParticipant = useZocksStore(selectLocalParticipant)

  const remoteParticipants = useSortRemoteParticipantsForGridView(pageSize)
  const allParticipants = [localParticipant, ...remoteParticipants]

  const { displayedParticipants, hasNextPage, hasPreviousPage, nextPage, previousPage } = usePagedParticipants(
    allParticipants,
    pageSize
  )

  const gridClass = getGridClassForParticipants(Math.min(pageSize, allParticipants.length))

  const ParticipantElement = participantElement ?? Participant

  return (
    <div className='participants-grid-view'>
      {hasPreviousPage && <PreviousButton onClick={previousPage} />}
      <div className={`participants-grid-view__grid ${gridClass}`}>
        {displayedParticipants.map((participant) => (
          <ParticipantElement key={participant.id} participant={participant} withAudio={true} />
        ))}
      </div>
      {hasNextPage && <NextButton onClick={nextPage} />}
    </div>
  )
}

const getGridClassForParticipants = (numberOfParticipants: number): string => {
  switch (true) {
    case numberOfParticipants <= 1:
      return 'participants-grid-view__grid--1x1'
    case numberOfParticipants === 2:
      return 'participants-grid-view__grid--2x1'
    case numberOfParticipants <= 4:
      return 'participants-grid-view__grid--2x2'
    case numberOfParticipants <= 6:
      return 'participants-grid-view__grid--3x2'
    case numberOfParticipants <= 9:
      return 'participants-grid-view__grid--3x3'
    case numberOfParticipants <= 16:
      return 'participants-grid-view__grid--4x4'
    default:
      return 'participants-grid-view__grid--5x5'
  }
}

const PreviousButton: React.FC<{ onClick: () => void }> = ({ onClick }) => (
  <button
    className='participants-grid-view__button participants-grid-view__previous-button'
    onClick={onClick}
    aria-label='Previous'
  >
    <div className='participants-grid-view__previous-button-icon' />
  </button>
)

const NextButton: React.FC<{ onClick: () => void }> = ({ onClick }) => (
  <button
    className='participants-grid-view__button participants-grid-view__next-button'
    onClick={onClick}
    aria-label='Next'
  >
    <div className='participants-grid-view__next-button-icon' />
  </button>
)
